@@ -24,7 +24,6 @@
 #include "server.h"
 #include "sinkinput.h"
 #include "canberracontext.h"
-#include <pulse/channelmap.h>
 
 namespace QPulseAudio
 {
@@ -44,6 +43,10 @@ Sink::~Sink()
 void Sink::update(const pa_sink_info *info)
 {
     updateDevice(info);
+    if (m_sourceIndex != info->monitor_source) {
+        m_sourceIndex = info->monitor_source;
+        Q_EMIT sourceIndexChanged();
+    }
 }
 
 void Sink::setVolume(qint64 volume)
@@ -130,4 +133,9 @@ void Sink::switchStreams()
     });
 }
 
+quint32 Sink::sourceIndex() const
+{
+    return m_sourceIndex;
+}
+
 } // QPulseAudio
